@@ -85,6 +85,7 @@ class fMMS_config:
 	def get_imgdir(self):
 		return self.client.get_string(self._fmmsdir + "imgdir")
 		
+	""" note this takes the *id* from gconf and not the *display name* """
 	def set_apn(self, apn):
 		#apn = apn.replace(" ", "@32@")
 		#self.client.set_string(self._fmmsdir + "apn_nicename", apn)
@@ -109,7 +110,27 @@ class fMMS_config:
 		proxy = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http')
 		proxyport = self.client.get_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port')
 		return proxy, proxyport
+	
+	def get_gprs_apns(self):
+		# get all IAP's
+		dirs = self.client.all_dirs('/system/osso/connectivity/IAP')
+		apnlist = []
+		for subdir in dirs:
+			# get all sub entries.. this might be costy?
+			all_entries = self.client.all_entries(subdir)
+			# this is a big loop as well, possible to make it easier?
+			# make this faster
+			for entry in all_entries:
+				(path, sep, shortname) = entry.key.rpartition('/')
+				# this SHOULD always be a int
+				if shortname == 'type' and entry.value.type == gconf.VALUE_STRING and entry.value.get_string() == "GPRS":	
+					# split it so we can get the id
+					#(spath, sep, apnid) = path.rpartition('/')
+					apname = self.client.get_string(path + '/name')
+					apnlist.append(apname)
 		
+		return apnlist
+	
 	""" get the gconf alias for the name, be it the real name or
 	an arbitrary string """
 	def get_apnid_from_name(self, apnname):
