@@ -14,6 +14,7 @@ import locale
 import osso
 import fmms_config as fMMSconf
 import fmms_sender_ui as fMMSSenderUI
+import contacts as ContactH
 import gobject
 import dbus
 
@@ -23,6 +24,7 @@ class fMMS_GUI(hildon.Program):
 		self.config = fMMSconf.fMMS_config()
 		self._mmsdir = self.config.get_mmsdir()
 		self._pushdir = self.config.get_pushdir()
+		self.ch = ContactH.ContactHandler()
 	
 		if not os.path.isdir(self._mmsdir):
 			print "creating dir", self._mmsdir
@@ -43,21 +45,28 @@ class fMMS_GUI(hildon.Program):
 		pan = hildon.PannableArea()
 		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
 		
+		
+		### TODO: dont hardcode the values here.. oh well
 		iconcell = gtk.CellRendererPixbuf()
+		photocell = gtk.CellRendererPixbuf()
 		textcell = gtk.CellRendererText()
+		iconcell.set_fixed_size(48, 64)
 		cell2 = gtk.CellRendererText()
 		cell2.set_property('xalign', 1.0)
+		photocell.set_property('xalign', 1.0)
+		photocell.set_fixed_size(64, 64)
 		textcell.set_property('mode', gtk.CELL_RENDERER_MODE_INERT)
-		textcell.set_fixed_size(-1, 60)
+		textcell.set_fixed_size(650, 64)
+		textcell.set_property('xalign', 0.0)
 		
-		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, str, str)
+		self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, str)
 		treeview = hildon.GtkTreeView(gtk.HILDON_UI_MODE_EDIT)
 		treeview.set_model(self.liststore)
 
 		
 		icon_col = gtk.TreeViewColumn('Icon')
 		sender_col = gtk.TreeViewColumn('Sender')
-		placeholder_col = gtk.TreeViewColumn('Placeholder')
+		placeholder_col = gtk.TreeViewColumn('Photo')
 		
 		
 		self.add_buttons_liststore()
@@ -67,17 +76,16 @@ class fMMS_GUI(hildon.Program):
 		treeview.append_column(placeholder_col)
 		
 		icon_col.pack_start(iconcell, False)
-		icon_col.set_attributes(iconcell, pixbuf=0) 
+		icon_col.set_attributes(iconcell, pixbuf=0)
 		sender_col.pack_start(textcell, True)
 		sender_col.set_attributes(textcell, markup=1)
-		placeholder_col.pack_start(cell2, True)
-		placeholder_col.set_attributes(cell2, markup=2)
+		placeholder_col.pack_end(photocell, False)
+		placeholder_col.set_attributes(photocell, pixbuf=2)
 		
 		selection = treeview.get_selection()
 		#selection.set_mode(gtk.SELECTION_SINGLE)
 		treeview.connect('hildon-row-tapped', self.show_mms)
 		
-		
 		self.treeview = treeview
 		pan.add_with_viewport(treeview)
 		self.window.add(pan)
@@ -296,12 +304,23 @@ class fMMS_GUI(hildon.Program):
 				varlist = self._read_push_as_list(self._pushdir + fname)
 				sender = varlist['From']
 				sender = sender.replace("/TYPE=PLMN", "")
+				
+				sendername = self.ch.get_name_from_number(sender)
+				photo = icon_theme.load_icon("general_default_avatar", 48, 0)
+				if sendername != None:
+					sender = sendername + ' <span size="smaller">(' + sender + ')</span>'
+					phototest = self.ch.get_photo_from_name(sendername, 64)
+					if phototest != None:	
+						photo = phototest
+						#print "loaded photo:", photo.get_width(), photo.get_height()
+	
 				#title = sender + " - " + mtime
+				
 				if self._is_fetched_push(fname):
 					icon = icon_theme.load_icon("general_sms", 48, 0)
 				else:
 					icon = icon_theme.load_icon("chat_unread_sms", 48, 0)
-				self.liststore.append([icon, sender + '  <span foreground="#666666" size="smaller"><sup>' + mtime + '</sup></span>\n<span foreground="#666666" size="x-small">' + fname + '</span>', "placeholder", fname])
+				self.liststore.append([icon, sender + '  <span foreground="#666666" size="smaller"><sup>' + mtime + '</sup></span>\n<span foreground="#666666" size="x-small">' + fname + '</span>', photo, fname])
 	""" lets call it quits! """
 	def quit(self, *args):
 		gtk.main_quit()
@@ -417,7 +436,8 @@ class fMMS_GUI(hildon.Program):
 
 	""" this function takes the FILENAME, not the full path """
 	def _is_fetched_push(self, filename):
-		if os.path.isdir(self._mmsdir + filename):
+		path = self._mmsdir + filename
+		if os.path.isdir(path):
 			if os.path.isfile(self._mmsdir + filename + "/message"):
 				return True
 		else:
