@@ -304,9 +304,13 @@ class MMSSender:
 		out = res.read()
 		print "MMSC RESPONDED:", out
 		
-		decoder = mms_pdu.MMSDecoder()
-		data = array.array('B')
-		for b in out:
-			data.append(ord(b))
-		outparsed = decoder.decodeResponseHeader(data)
+		try:
+			decoder = mms_pdu.MMSDecoder()
+			data = array.array('B')
+			for b in out:
+				data.append(ord(b))
+			outparsed = decoder.decodeResponseHeader(data)
+		except:
+			outparsed = out
+		
 		return res.status, res.reason, outparsed
\ No newline at end of file
